@@ -32,17 +32,9 @@
 #include <gio/gio.h>
 
 #include <gdk/gdk.h>
-
-#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
-#ifndef GDK_IS_X11_DISPLAY
-#define GDK_IS_X11_DISPLAY(display) 1
-#endif
-#endif
 
-#ifdef WITH_SMCLIENT
 #include "eggsmclient.h"
-#endif
 
 #include "terminal-accels.h"
 #include "terminal-app.h"
@@ -160,7 +152,7 @@ method_call_cb (GDBusConnection *connection,
 		int argc;
 		GError *error = NULL;
 
-        g_variant_get (parameters, "(@ay@ay@ay@ay@i@ay)",
+        g_variant_get (parameters, "(@ay@ay@ay@ayi@ay)",
                        &v_wd, &v_display, &v_sid, &v_envv, &initial_workspace, &v_argv);
 
 		working_directory = ay_to_string (v_wd, &error);
@@ -317,7 +309,7 @@ name_lost_cb (GDBusConnection *connection,
 	OwnData *data = (OwnData *) user_data;
 	GError *error = NULL;
 	char **envv;
-	int envc, i;
+	int i;
 	GVariantBuilder builder;
 	GVariant *value;
 	GString *string;
@@ -353,21 +345,15 @@ name_lost_cb (GDBusConnection *connection,
 	g_variant_builder_add (&builder, "@ay", string_to_ay (data->options->startup_id));
 
 	string = g_string_new (NULL);
-	envv = g_listenv ();
-	envc = g_strv_length (envv);
-	for (i = 0; i < envc; ++i)
+	envv = g_get_environ ();
+	for (i = 0; envv[i]; ++i)
 	{
-		const char *value;
-
-		value = g_getenv (envv[i]);
-		if (value == NULL)
-			continue;
-
 		if (i > 0)
 			g_string_append_c (string, '\0');
 
-		g_string_append_printf (string, "%s=%s", envv[i], value);
+		g_string_append (string, envv[i]);
 	}
+	g_strfreev (envv);
 
 	len = string->len;
 	s = g_string_free (string, FALSE);
@@ -442,7 +428,6 @@ name_lost_cb (GDBusConnection *connection,
  *
  */
 
-#ifdef GDK_WINDOWING_X11
 /* Copied from libcaja/caja-program-choosing.c; Needed in case
  * we have no DESKTOP_STARTUP_ID (with its accompanying timestamp).
  */
@@ -493,7 +478,6 @@ slowly_and_stupidly_obtain_timestamp (Display *xdisplay)
 
 	return event.xproperty.time;
 }
-#endif
 
 static char *
 get_factory_name_for_display (const char *display_name)
@@ -571,6 +555,8 @@ main (int argc, char **argv)
 
 	working_directory = g_get_current_dir ();
 
+	gdk_set_allowed_backends ("x11");
+
 	/* Now change directory to $HOME so we don't prevent unmounting, e.g. if the
 	 * factory is started by caja-open-terminal. See bug #565328.
 	 * On failure back to /.
@@ -588,9 +574,7 @@ main (int argc, char **argv)
 	                                  &argc, &argv,
 	                                  &error,
 	                                  gtk_get_option_group (TRUE),
-#ifdef WITH_SMCLIENT
 	                                  egg_sm_client_get_option_group (),
-#endif
 	                                  NULL);
 
 	g_free (working_directory);
@@ -615,8 +599,7 @@ main (int argc, char **argv)
 	display_name = gdk_display_get_name (display);
 	options->display_name = g_strdup (display_name);
 
-#ifdef GDK_WINDOWING_X11
-	if (GDK_IS_X11_DISPLAY(display) && options->startup_id == NULL)
+	if (options->startup_id == NULL)
 	{
 		/* Create a fake one containing a timestamp that we can use */
 		Time timestamp;
@@ -625,7 +608,6 @@ main (int argc, char **argv)
 
 		options->startup_id = g_strdup_printf ("_TIME%lu", timestamp);
 	}
-#endif
 
 	if (options->use_factory)
 	{
@@ -639,8 +621,8 @@ main (int argc, char **argv)
 		data->argv = argv_copy;
 		data->argc = argc_copy;
 
-        gtk_init(&argc, &argv);
-        options->initial_workspace = get_initial_workspace ();
+		gtk_init(&argc, &argv);
+		options->initial_workspace = get_initial_workspace ();
 
 		owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
 		                           data->factory_name,
